@@ -1,2 +1,2 @@
 from one_table.Utils import get_iso_8601_date
-from Table import Table
+from one_table.Table import Table
